@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2007 JGoodies Karsten Lentzsch. All Rights Reserved.
+ * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -68,7 +68,7 @@ import com.jgoodies.forms.layout.FormLayout;
  * Demonstrates how to bind different value types to Swing components.
  *
  * @author Karsten Lentzsch
- * @version $Revision: 1.24 $
+ * @version $Revision: 1.26 $
  *
  * @see com.jgoodies.binding.adapter.BasicComponentFactory
  * @see com.jgoodies.binding.adapter.Bindings
@@ -76,7 +76,7 @@ import com.jgoodies.forms.layout.FormLayout;
 public final class ComponentsExample {
 
     // Holds an ExampleBean and vends ValueModels that adapt its properties.
-    private final ExamplePresentationModel<ExampleBean> presentationModel;
+    private final ExamplePresentationModel presentationModel;
 
     // Text Components
     private JTextField     textField;
@@ -138,7 +138,7 @@ public final class ComponentsExample {
      * Constructs the 'Components' example on an instance of ExampleBean.
      */
     public ComponentsExample() {
-        presentationModel = new ExamplePresentationModel<ExampleBean>(new ExampleBean());
+        presentationModel = new ExamplePresentationModel(new ExampleBean());
     }
 
 
@@ -586,7 +586,8 @@ public final class ComponentsExample {
      * A custom PresentationModel that provides a SelectionInList
      * for the bean's ListModel and the bean's list selection.
      */
-    private static final class ExamplePresentationModel<B> extends PresentationModel<B> {
+    private static final class ExamplePresentationModel
+        extends PresentationModel<ExampleBean> {
 
         /**
          * Holds the bean's list model plus a selection.
